#!/bin/sh

# if no args specified, show usage
if [ $# = 0 ]; then
  echo "Usage: crawl [-n nutch dir] [-c crawl dir] [-f number of URls to fetch]"
  echo "  -n    Required. The absolute path to the nutch distribution,"
  echo "        such that \$NUTCH_HOME/bin/nutch resolves"
  echo "        to the nutch script."
  echo "  -c    Required. The absolue path to a directory that contains"
  echo "        the crawl and indexes directories."
  echo "  -i    Required. The absolute path to the web.xml file for the search application."
  echo "  -f    Optional. An integer which limits how many "
  echo "        URLs will be fetched."  
  exit 1
fi

# set flag vars to empty
n= c= f=

# leading colon so that we do error handling here
while getopts :n:c:f:i: opt
  do
  case $opt in
  n)  n=$OPTARG
      ;;
  c)  c=$OPTARG
      ;;
  f)  f=$OPTARG
      ;;
  i)  i=$OPTARG
      ;;      
  '?')  echo "$0: invalid option -$OPTARG" >&2
        echo "USAGE: $0 [-n nutch dir] [-c crawl dir] [-i tomcat webapp] [-f number of URLs to fetch]"
  esac
done

# remove options, leave arguments
shift $((OPTIND - 1))

# do we have the required -n and -c args?
if [ -z "$n" ] || [ -z "$c" ] || [ -z "$i" ]; then
  echo " [-n nutch dir] [-c crawl dir] [-i tomcat webapp] are required"
  exit 1
fi

# change to the crawl dir
cd $c

if [ -z "$f" ]; then
  f=50
fi

# test if the crawl dir is present. If not is is a sign that inject
# been run.
crawl="ls . | grep crawl"
x=$(eval $crawl)
if [ "X$x" != "Xcrawl" ]; then
  echo "The crawl directory doesn't exist. Have you run drnutch with -u set?"
  echo "The injection tool typically creates the crawl directory and running"
  echo "drnutch with -u set runs the injection tool."
  exit 1
fi

# run the generate tool
$n/bin/nutch generate crawl/crawldb crawl/segments -topN $f

# generate created a new segment. find it and save it to s
s=`ls -d $c/crawl/segments/2* | tail -1`
echo "Segment: $s"

# run the fetch tool
$n/bin/nutch fetch $s

# update the links db
$n/bin/nutch updatedb crawl/crawldb $s

# invert links
$n/bin/nutch invertlinks crawl/linkdb -dir crawl/segments

## create the index

# test if the indexes dir is present. If not is is a sign that this is
# the first crawl.
indexes="ls ./crawl | grep indexes"
x=$(eval $indexes)
if [ "X$x" != "Xindexes" ]; then
  echo "No indexes detected; first crawl"
  indexes="crawl/indexes"
else
  echo "Indexes found; will merge"
  indexes="crawl/newindexes"
  merge="yes"
fi

$n/bin/nutch index $indexes crawl/crawldb crawl/linkdb crawl/segments/*

# De-duplicate indexes
$n/bin/nutch dedup $indexes

if [ $merge ]; then
  # Merge indexes
  $n/bin/nutch merge crawl/merged crawl/indexes crawl/newindexes
  
  touch crawl/merged/index.done
  rm -fd -R crawl/newindexes
  rm -fd -R crawl/indexes
  mkdir crawl/indexes
  mv crawl/merged crawl/indexes/part-00000
fi

# Tell Tomcat to reload index
touch $i