#!/bin/sh

# if no args specified, show usage
if [ $# = 0 ]; then
  echo "Usage: inject [-n nutch dir] [-c crawl dir] [-u URLs dir]"
  echo "  -n    Required. The path to the nutch distribution,"
  echo "        such that \$NUTCH_HOME/bin/nutch resolves"
  echo "        to the nutch script."
  echo "  -c    Required. The path to a directory that contains"
  echo "        the crawl and indexes directories."
  echo "  -u    Required. A directory containing flat files"
  echo "        of links to be injected for crawling."
  exit 1
fi

# set flag vars to empty
n= c= u=

# leading colon so that we do error handling here
while getopts :n:c:u: opt
  do
  case $opt in
  n)  n=$OPTARG
      ;;
  c)  c=$OPTARG
      ;;
  u)  u=$OPTARG
      ;;
  '?')  echo "$0: invalid option -$OPTARG" >&2
        echo "USAGE: $0 [-n nutch dir] [-c crawl dir] [-u URLs dir]"
  esac
done

# remove options, leave arguments
shift $((OPTIND - 1))

# do we have the required -n, -c and -u‚ args?
if [ -z "$n" ] || [ -z "$c" ] || [ -z "$u" ]; then
  echo " [-n nutch dir] [-c crawl dir] and [-u URLs dir] are required"
  exit 1
fi

# change to the crawl dir
cd $c

# if u is present, inject URLs
echo "injecting $u"
$n/bin/nutch inject crawl/crawldb $u
